# OpenFisca Japan （支援みつもりヤドカリくん）

## 概要
日本の制度のシミュレーターです。  
世帯の情報を入力すると、利用可能な制度と手当額が簡易的に算出されます。  
以下の支援制度に対応しています。

- 児童手当
- 児童扶養手当
- 特別児童扶養手当
- 障害児福祉手当
- 生活福祉資金貸付制度
- 生活保護
- 高等学校奨学給付金
- 高等学校等就学支援金
- 児童育成手当（東京都）
- 障害児童育成手当（東京都）
- 重度心身障害者手当（東京都）
- 受験生チャレンジ支援貸付事業（東京都）
- 健康管理費用
- 健康管理支援事業
- 先天性の傷病治療によるC型肝炎患者に係るQOL向上等のための調査研究事業
- 障害基礎年金
- 特別障害者手当
- 傷病手当金
- 災害弔慰金（能登半島地震被災地）
- 災害障害見舞金（能登半島地震被災地）
- 被災者生活再建支援制度（能登半島地震被災地）
- 災害援護資金（能登半島地震被災地）

## 作成Webアプリ
[支援みつもりヤドカリくん](https://shien-yadokari.proj-inclusive.org/)に作成されたWebアプリが公開されています。  
mainブランチのソースコードがビルド・デプロイされています。  
フロントエンド(React)はCloudflare Pages、バックエンド(OpenFisca)はGoogle CloudのCloud Runでビルド・デプロイされています。

## 開発参加方法
- リポジトリをフォークし、**develop**ブランチ（あるいはそこから新たに切ったブランチ）にチェックアウトしてコミットを行ってください。（developブランチに最新の開発状況が反映されています。）
  - （参考）[フォーク・クローン・プルリクエストの流れ](https://techtechmedia.com/how-to-fork-github/) 
- プルリクエストでマージを要求するブランチはdevelopブランチとしてください
  - デフォルトではmainブランチとなっているため、developブランチに変更する必要があります
- Issueに着手される際は、他コントリビューターと重複を防ぐため、着手したことをコメントに記載お願いします
  - 1つのIssueを複数人で分担して進めていただいても構いません
  - 部分的なpull requestやドラフトのpull requestを出していただいても構いません

## その他の情報

project-inclusiveの開発方針やOpenFiscaそのもの等の情報は、[本リポジトリのDocumentPages](https://project-inclusive.github.io/OpenFisca-Japan/)に記載しています。


## お問い合わせ
- [proj-inclusive](https://www.proj-inclusive.org/)
- [防窮研究所](https://www.facebook.com/Institute.for.Poverty.Prevention)

